import { useState } from "react";
import { Link } from "react-router-dom";
import { connect } from "react-redux";

import { actionSearch } from "store/actions/actionSearch";

import "./Main.css";

const Search = ({ onSearch, snippets }) => {
	const [request, setRequest] = useState("");
	return (
		<>
			<Link to='/work'>
				<div className='btn_block_back'>
					<button className='btn_search'>Back to Work Page</button>
				</div>
			</Link>
			<br />
			<br />
			<div>
				<input
					className='field_for_search'
					value={request}
					onChange={e => setRequest(e.target.value)}
					type='search'
					placeholder='Type name or description'
					aria-label='Search'
				/>
				<br />
				<div className='btn_block_search'>
					<button className='btn_search' onClick={() => onSearch(request)}>
						Search
					</button>
				</div>
			</div>
			<div className='snippet_block'>
				{snippets?.map(snippet => (
					<div key={snippet._id} className='snippet'>
						<img src={`${process.env.PUBLIC_URL}/img/code.png`} alt='code'></img>
						<div className='block_content'>
							<p>{`Name: ${snippet.title}` || "Project without name"}</p>
							<p>{`Description: ${snippet.description}` || ""}</p>
							<p>{`Owner: ${snippet.owner.login}`}</p>
							<div className='btn_center'>
								<Link to={"/search-project/" + snippet._id}>
									<button className='btn_search'>Open project</button>
								</Link>
							</div>
						</div>
					</div>
				))}
			</div>
		</>
	);
};

const ConnectFormSearch = connect(
	state => ({
		snippets: state?.promise?.searchSnippet?.payload?.data?.SnippetFind,
	}),
	{ onSearch: actionSearch },
)(Search);

export default ConnectFormSearch;
